@@ -6,6 +6,8 @@
         options(descr.plot = TRUE)
     if(is.null(getOption("descr.warn")))
         options(descr.warn = TRUE)
+    if(is.null(getOption("descr.na.replacement")))
+        options(descr.na.replacement = "NA")
 
 }
 
@@ -111,3 +113,16 @@ LogRegR2 <- function(model)
     x
 }
 
+no.drop.levels <- function(x)
+{
+    if(sum(is.na(x)) > 0){
+        nl <- length(levels(x)) + 1
+        lv <- c(levels(x), options("descr.na.replacement"))
+        io <- is.ordered(x)
+        x <- as.numeric(x)
+        x[is.na(x)] <- nl
+        x <- factor(x, levels = 1:nl, labels = lv, ordered = io)
+    }
+    x
+}
+
